// Copyright 2024 The Oppia Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Mobile menu service for new lesson player.
 */

import { Injectable } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';

@Injectable({
  providedIn: 'root'
})
export class MobileMenuService {
  private menuVisibleSubject = new BehaviorSubject<boolean>(false);

  getMenuVisibility(): Observable<boolean> {
    return this.menuVisibleSubject.asObservable();
  }

  toggleMenuVisibility(): void {
    const currentValue = this.menuVisibleSubject.getValue();
    this.menuVisibleSubject.next(!currentValue);
  }
}
