// Copyright 2022 The Oppia Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Component for the music notes input response.
 *
 * IMPORTANT NOTE: The naming convention for customization args that are passed
 * into the directive is: the name of the parameter, followed by 'With',
 * followed by the name of the arg.
 */

import { Component, Input, OnInit } from '@angular/core';
import { downgradeComponent } from '@angular/upgrade/static';
import { HtmlEscaperService } from 'services/html-escaper.service';

@Component({
  selector: 'oppia-response-music-notes-input',
  templateUrl: './music-notes-input-response.component.html'
})
export class ResponseMusicNotesInput implements OnInit {
  @Input() answer;
  displayedAnswer: string;

  constructor(
    private htmlEscaperService: HtmlEscaperService
  ) {}

  ngOnInit(): void {
    let _answer = this.htmlEscaperService.escapedJsonToObj(this.answer);
    let _notes = [];
    for (let i = 0; i < Object.keys(_answer).length; i++) {
      if (_answer[i].readableNoteName) {
        _notes.push(_answer[i].readableNoteName);
      }
    }

    if (_notes.length > 0) {
      this.displayedAnswer = _notes.join(', ');
    } else {
      this.displayedAnswer = 'No answer given.';
    }
  }
}

angular.module('oppia').directive(
  'oppiaResponseMusicNotesInput', downgradeComponent(
    {component: ResponseMusicNotesInput}
  ) as angular.IDirectiveFactory);
